@@ -1,4 +1,4 @@
-# coding: utf8
+# coding=utf-8
 import json
 import logging
 from six.moves.urllib.parse import urlencode
@@ -6,7 +6,6 @@ import requests
 from oauthlib.oauth1 import SIGNATURE_RSA
 from requests_oauthlib import OAuth1
 
-
 log = logging.getLogger(__name__)
 
 
@@ -17,7 +16,8 @@ class AtlassianRestAPI(object):
     form_token_headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
                           'X-Atlassian-Token': 'no-check'}
 
-    def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest', verify_ssl=True, session=None, oauth=None):
+    def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest',
+                 verify_ssl=True, session=None, oauth=None, is_advanced_mode=False):
         self.url = url
         self.username = username
         self.password = password
@@ -25,6 +25,8 @@ class AtlassianRestAPI(object):
         self.verify_ssl = verify_ssl
         self.api_root = api_root
         self.api_version = api_version
+        if is_advanced_mode:
+            self.is_advanced_mode = is_advanced_mode
         if session is None:
             self._session = requests.Session()
         else:
@@ -32,18 +34,27 @@ class AtlassianRestAPI(object):
         if username and password:
             self._create_basic_session(username, password)
         elif oauth is not None:
-            self._create_oauth_session(oauth, timeout)
+            self._create_oauth_session(oauth)
 
     def _create_basic_session(self, username, password):
         self._session.auth = (username, password)
 
-    def _create_oauth_session(self, oauth_dict, timeout=60):
+    def _create_oauth_session(self, oauth_dict):
         oauth = OAuth1(oauth_dict['consumer_key'],
                        rsa_key=oauth_dict['key_cert'], signature_method=SIGNATURE_RSA,
                        resource_owner_key=oauth_dict['access_token'],
                        resource_owner_secret=oauth_dict['access_token_secret'])
         self._session.auth = oauth
 
+    def _update_header(self, key, value):
+        """
+        Update header for exist session
+        :param key:
+        :param value:
+        :return:
+        """
+        self._session.headers.update({key: value})
+
     def log_curl_debug(self, method, path, data=None, headers=None, trailing=None, level=logging.DEBUG):
         """
 
@@ -129,6 +140,8 @@ class AtlassianRestAPI(object):
             log.error('Received: {0}\n Not Found'.format(response.status_code))
         elif response.status_code == 403:
             log.error('Received: {0}\n Forbidden. Please, check permissions'.format(response.status_code))
+        elif response.status_code == 405:
+            log.error('Received: {0}\n Method not allowed'.format(response.status_code))
         elif response.status_code == 409:
             log.error('Received: {0}\n Conflict \n '.format(response.status_code, response_content))
         elif response.status_code == 413:
@@ -161,11 +174,13 @@ class AtlassianRestAPI(object):
         if not_json_response:
             return answer.content
         else:
+            if not answer.text:
+                return None
             try:
                 return answer.json()
             except Exception as e:
                 log.error(e)
-                return
+                return answer.text
 
     def post(self, path, data=None, headers=None, files=None, params=None, trailing=None):
         try:
